==> servicecatalog-0.8.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/AcceptedPortfolioShareResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;
/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-acceptedportfolioshare.html
 */
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.AcceptedPortfolioShareResource")
public class AcceptedPortfolioShareResource extends software.amazon.awscdk.Resource {
    protected AcceptedPortfolioShareResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.AcceptedPortfolioShareResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::AcceptedPortfolioShare``.
     * @param parent the ``cdk.Construct`` this ``AcceptedPortfolioShareResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``AcceptedPortfolioShareResource``
     */
    public AcceptedPortfolioShareResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.AcceptedPortfolioShareResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;
}

==> servicecatalog-0.9.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/AcceptedPortfolioShareResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-acceptedportfolioshare.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:55:36.563Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.AcceptedPortfolioShareResource")
public class AcceptedPortfolioShareResource extends software.amazon.awscdk.Resource {
    protected AcceptedPortfolioShareResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.AcceptedPortfolioShareResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::AcceptedPortfolioShare``.
     * @param parent the ``cdk.Construct`` this ``AcceptedPortfolioShareResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``AcceptedPortfolioShareResource``
     */
    public AcceptedPortfolioShareResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.AcceptedPortfolioShareResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.servicecatalog.AcceptedPortfolioShareId getRef() {
        return this.jsiiGet("ref", software.amazon.awscdk.services.servicecatalog.AcceptedPortfolioShareId.class);
    }
}
